pub struct RequestDispatcher { /* private fields */ }Expand description
A dispatcher that can drive requests through the RustAPI pipeline (interceptors + layers + router) without any network or serialization overhead.
Obtained via crate::RustApi::request_dispatcher.
Implementations
Sourceimpl RequestDispatcher
impl RequestDispatcher
Sourcepub fn state_ref(&self) -> Arc<Extensions>
pub fn state_ref(&self) -> Arc<Extensions>
Returns the shared state Extensions from the underlying router.
Useful for in-process request construction to preserve State<T> etc.